@@ -1,20 +1,20 @@
-from path import path
 import logging
 import os
+from path import path
 import sys
 
-__version__ = '0.2'
+from confduino.about import __version__
+
 
 log = logging.getLogger(__name__)
-# log=logging
 
-log.debug('version=' + __version__)
+log.debug('version=%s', __version__)
 
 _ARDUINO_PATH = None
 
 
 def arduino_default_path():
-    'platform specific default root path'
+    """platform specific default root path."""
     if sys.platform == 'darwin':
         s = path('/Applications/Arduino.app/Contents/Resources/Java')
     elif sys.platform == 'win32':
@@ -30,7 +30,7 @@ def set_arduino_path(directory):
 
 
 def arduino_path():
-    'expanded root path, ARDUINO_HOME env var or arduino_default_path()'
+    """expanded root path, ARDUINO_HOME env var or arduino_default_path()"""
 
     x = _ARDUINO_PATH
     if not x:
