@@ -1,7 +1,6 @@
 from confduino.boardlist import boards_txt, boards
 from confduino.boardremove import remove_board
 from confduino.util import bunch2properties
-from entrypoint2 import entrypoint
 import logging
 
 log = logging.getLogger(__name__)
@@ -10,18 +9,19 @@ log = logging.getLogger(__name__)
 
 
 def install_board(board_id, board_options, hwpack='arduino', replace_existing=False):
-    '''install board in boards.txt
+    """install board in boards.txt.
 
     :param board_id: string identifier
     :param board_options: dict like
     :param replace_existing: bool
     :rtype: None
-    '''
+
+    """
     doaction = 0
     if board_id in boards(hwpack).keys():
-        log.debug('board already exists:' + board_id)
+        log.debug('board already exists: %s', board_id)
         if replace_existing:
-            log.debug('remove board: %s' % (board_id))
+            log.debug('remove board: %s' , board_id)
             remove_board(board_id)
             doaction = 1
     else:
