@@ -7,13 +7,14 @@ log = logging.getLogger(__name__)
 
 @entrypoint
 def remove_examples_all():
-    '''remove arduino/examples/all directory
+    """remove arduino/examples/all directory.
 
     :rtype: None
-    '''
+
+    """
     d = examples_all_dir()
     if d.exists():
-        log.debug('remove %s' % (d))
+        log.debug('remove %s', d)
         d.rmtree()
     else:
-        log.debug('nothing to remove:%s' % (d))
+        log.debug('nothing to remove: %s', d)
