@@ -7,10 +7,11 @@ from entrypoint2 import entrypoint
 def install_metaboard(
     replace_existing=False,
 ):
-    '''install metaboard
+    """install metaboard.
 
     http://metalab.at/wiki/Metaboard
-    '''
+
+    """
     metaboard = AutoBunch()
     metaboard.name = 'Metaboard'
 
@@ -24,6 +25,6 @@ def install_metaboard(
 
     metaboard.upload.disable_flushing = 'true'
 
-    id = 'metaboard'
+    board_id = 'metaboard'
 
-    install_board(id, metaboard, replace_existing=replace_existing)
+    install_board(board_id, metaboard, replace_existing=replace_existing)
