@@ -1,4 +1,5 @@
-from confduino.boardlist import boards, boards_txt, board_names
+from confduino.boardlist import board_names
+from confduino.boardlist import boards_txt
 from confduino.boardremove import remove_board
 from confduino.hwpacklist import hwpack_names
 from entrypoint2 import entrypoint
@@ -7,7 +8,7 @@ import psidialogs
 
 @entrypoint
 def remove_boards_gui(hwpack=''):
-    'remove boards by GUI'
+    """remove boards by GUI."""
     if not hwpack:
         if len(hwpack_names()) > 1:
             hwpack = psidialogs.choice(hwpack_names(),
@@ -15,15 +16,16 @@ def remove_boards_gui(hwpack=''):
                                        title='select')
         else:
             hwpack = hwpack_names()[0]
-    print hwpack, 'selected'
+    print('%s selected' % hwpack)
 
     if hwpack:
         sel = psidialogs.multi_choice(board_names(hwpack),
-                                      'select boards to remove from %s!' % boards_txt(hwpack),
+                                      'select boards to remove from %s!' % boards_txt(
+                                          hwpack),
                                       title='remove boards')
-        print sel, 'selected'
+        print('%s selected' % sel)
 
         if sel:
             for x in sel:
                 remove_board(x)
-                print x + ' was removed'
+                print('%s was removed' % x)
