@@ -7,11 +7,12 @@ log = logging.getLogger(__name__)
 
 @entrypoint
 def remove_lib(lib_name):
-    '''remove library
+    """remove library.
 
     :param lib_name: library name (e.g. 'PS2Keyboard')
     :rtype: None
-    '''
+
+    """
     targ_dlib = libraries_dir() / lib_name
-    log.debug('remove %s' % (targ_dlib))
+    log.debug('remove %s', targ_dlib)
     targ_dlib.rmtree()
