@@ -1,4 +1,4 @@
-from bunch import unbunchify
+from munch import unmunchify
 from confduino.boardlist import boards, board_names
 from confduino.hwpacklist import hwpack_names
 from entrypoint2 import entrypoint
@@ -8,8 +8,7 @@ log = logging.getLogger(__name__)
 
 
 def mcus():
-    '''MCU list
-    '''
+    """MCU list."""
     ls = []
     for h in hwpack_names():
         for b in board_names(h):
@@ -19,14 +18,13 @@ def mcus():
 
 
 def mcu(board_id, hwpack_id):
-    '''
-    '''
+    """"""
     board = boards(hwpack=hwpack_id)[board_id]
     return board.build.mcu
 
 
 @entrypoint
 def print_mcus():
-    ''' print boards from boards.txt'''
-    ls = unbunchify(mcus())
-    print '\n'.join(ls)
+    """print boards from boards.txt."""
+    ls = unmunchify(mcus())
+    print('\n'.join(ls))
