@@ -1,7 +1,6 @@
 from confduino.proglist import programmers_txt, programmers
 from confduino.progremove import remove_programmer
 from confduino.util import bunch2properties
-from entrypoint2 import entrypoint
 import logging
 
 log = logging.getLogger(__name__)
@@ -10,18 +9,19 @@ log = logging.getLogger(__name__)
 
 
 def install_programmer(programmer_id, programmer_options, replace_existing=False):
-    '''install programmer in programmers.txt
+    """install programmer in programmers.txt.
 
     :param programmer_id: string identifier
     :param programmer_options: dict like
     :param replace_existing: bool
     :rtype: None
-    '''
+
+    """
     doaction = 0
     if programmer_id in programmers().keys():
-        log.debug('programmer already exists:' + programmer_id)
+        log.debug('programmer already exists: %s', programmer_id)
         if replace_existing:
-            log.debug('remove programmer: %s' % (programmer_id))
+            log.debug('remove programmer: %s', programmer_id)
             remove_programmer(programmer_id)
             doaction = 1
     else:
